import { Config } from "../../interfaces";
import Provider from "../higher-order/Provider";
/**
 * Handles the cleanup and restart of the command executer.
 *
 * Kills the spawned process, kills the process running on the port to avoid conflicts and restarts a clean process.
 * @extends Provider
 * @category Core
 */
export default class Thread extends Provider {
    /**
     * The child process generated using `child_process.spawn`.
     */
    private childProcess;
    /**
     * The main command derived from `config.exec` which is passed to `childProcess` of this instance.
     */
    private command;
    /**
     * The arguments derived from `config.exec` which is passed to `childProcess` of this instance.
     */
    private args;
    /**
     * Create an instance of `Thread` which is responsible for managing the entire child process spawning and management.
     * @param {Config} config The configuration object.
     */
    constructor(config: Config);
    /**
     * Kill the process if it has been spawned. If not, fail silently.
     */
    private killProcess;
    /**
     * Try to kill the process running on the port specified in `config.port`. If not, fail silently.
     */
    private killPort;
    /**
     * Start the thread, executing the command specified in `config.exec`.
     * @param {string} root The root path to start the process.
     * @param {boolean} [restart] Whether this is a restart or not.
     */
    start(root: string, restart?: boolean): Promise<void>;
    /**
     * Restart the thread, executing the command specified in `config.exec`.
     * @param {string} root The root path to start the process.
     */
    restart(root: string): Promise<void>;
}
