import { FSWatcher } from "chokidar";
import { Config, WatcherEvent, WatcherListeners } from "../../interfaces";
import Provider from "../higher-order/Provider";
/**
 * The base watcher class, that handles all file watches and fires events accordingly.
 * @extends Provider
 * @category Core
 */
export default class Watcher extends Provider {
    /**
     * The paths generated by this `Watcher` instance, using the config.
     */
    private paths;
    /**
     * The root path generated by this `Watcher` instance, using the config.
     */
    private root;
    /**
     * The instance of the `chokidar` watcher that powers this wrapper class.
     */
    private instance;
    /**
     * The instance of `Thread` which manages the execution of commands on firing of watcher event.
     */
    private thread;
    /**
     * The list of handlers attached to events in this instance. Handlers can be attached to the `onBeforeStart`, `onStart`, `onBeforeChange`, `onChange`, `onBeforeStop` or `onStop` events.
     */
    private listeners;
    /**
     * Creates an instance of the `Watcher`.
     * @param {Config} config The base configuration for the watcher.
     * @param {WatcherListeners} [listeners] Optional listeners than can be passed to run custom functions before or after emitted events.
     */
    constructor(config: Config, listeners: WatcherListeners);
    /**
     * Bind all watcher events to the instance.
     */
    private bindWatcherEvents;
    /**
     * Allows attaching a handler to an watcher event. Does not attach event if `event` is not valid.
     * @param {WatcherEvent} event The event to fire this function for. Possible options are `onBeforeStart`, `onStart`, `onBeforeChange`, `onChange`, `onBeforeStop` and `onStop`.
     * @param {function} eventHandler The event handler function. Receives
     */
    on(event: WatcherEvent, eventHandler: Function): void;
    /**
     * Returns the instance of the internal watcher.
     */
    getInstance(): FSWatcher;
}
