import { Ora } from "ora";
import { Config } from "../../interfaces";
/**
 * The Display class is the primary class responsible for providing spinner visualisations.
 * @category Higher Order
 */
export default class Display {
    /**
     * The configuration object passed to this instance.
     */
    private config;
    /**
     * The `Ora` spinner instance which is useful for display purposes.
     */
    protected spinner: Ora;
    /**
     * A boolean to indicate if the process has started or not.
     */
    private started;
    /**
     * Create an instance of `Display` to handle all messages broadcasted on the terminal.
     * @param {Config} config The confguration object.
     */
    constructor(config: Config);
    /**
     * Display the `config.display.onBeforeStart` message with the spinner before executing.
     */
    onBeforeStart(): void;
    /**
     * Display the `config.display.onStart` message with the spinner after executing.
     */
    onStart(): void;
    /**
     * Display the `config.display.onBeforeRestart` message with the spinner before restarting.
     */
    onBeforeRestart(): void;
    /**
     * Display the `config.display.onRestart` message with the spinner after restarting.
     */
    onRestart(): void;
}
