import { Config } from "../../interfaces";
/**
 * A logger function which only logs only is the level of the message is greater than
 * or equal to the log level specificd in the config. Strings support Chalk template literals.
 * @category Higher Order
 */
export default class Logger {
    /**
     * The `Config` object provided to this instance.
     */
    private config;
    /**
     * Creates an instance of `Logger` to manage all kinds of logging.
     * @param {Config} config Creates an instance of `Logger`.
     */
    constructor(config: Config);
    /**
     * The is the internal print function used by the logger to check the `logLevel` and print messages to the terminal.
     * @param {any|any[]} message An item to be printed to the terminal.
     * @param {number} level The level of the log.
     * @param {string} prefix The string to prefix the log message with.
     */
    private print;
    private chalk;
    /**
     * Log a critical message. This exits the process.
     * @argument {any} error - Any valid error instance.
     */
    fatal(error: any | Array<any>): void;
    /**
     * Logs a critical message. Does not exit the process.
     * @argument {any|any[]} messages
     */
    error(...messages: any | Array<any>): void;
    /**
     * Logs a warning. Used to highlight cause of problems.
     * @argument {any|any[]} messages
     */
    warn(...messages: any | Array<any>): void;
    /**
     * Logs an informative message. Useful for general logging purposes.
     * @argument {any|any[]} messages
     */
    info(...messages: any | Array<any>): void;
    /**
     * Logs all messages useful while debugging specially. Useful for providing more context to advanced users.
     * @argument {any|any[]} messages
     */
    debug(...messages: any | Array<any>): void;
}
