/**
 * @packageModule
 * @module Utils
 */
import { Config, ConfigCheck } from "./interfaces";
/**
 * Loads a configuration object. Merging .nodehawkrc (if it exists) and the default configuration file. Otherwise returns the default configuration.
 * @module Utils
 * @category Core
 */
export declare function loadConfiguration(): Config;
/**
 * Checks whether the configuration object types match the ones expected.
 * @param {Config} config The configuration object to check.
 * @category Core
 */
export declare function checkConfig(config: Config): ConfigCheck;
/**
 * Returns a root-relative joined paths to with the supplied paths.
 *
 * @param {string} root A path string resolving to the root directory.
 * @param {(string|string[])} paths A string or an array of paths to resolve with respect to root.
 * @category Core
 */
export declare function generateBasePathRelativeToRoot(root: string, paths: string | string[]): string | string[];
/**
 * Clears the terminal screen.
 * @category Utils
 */
export declare function clearScreen(): void;
/**
 * Assign environemnt variables from the configuration to the process.
 * @param {Config} config The configuration object.
 * @category Core
 */
export declare function assignEnvironmentVariables(config: Config): void;
